@@ -45,6 +45,7 @@ my $cmd_out_tmp    = 'cmd.out';
 my $default_conf   = "$conf_dir/default_psad.conf";
 my $ignore_udp_conf = "$conf_dir/ignore_udp.conf";
 my $ignore_tcp_conf = "$conf_dir/ignore_tcp.conf";
+my $ignore_intf_conf = "$conf_dir/ignore_intf.conf";
 my $auto_blocking_conf = "$conf_dir/auto_blocking.conf";
 my $auto_dl5_blocking_conf = "$conf_dir/auto_min_dl5_blocking.conf";
 my $require_prefix_conf = "$conf_dir/require_DROP_syslog_prefix_str.conf";
@@ -66,6 +67,7 @@ my $test_exclude = '';
 my @tests_to_exclude = ();
 my $list_mode = 0;
 my $diff_mode = 0;
+my $test_limit = 0;
 my $saved_last_results = 0;
 my $test_system_install = 0;
 my $normal_root_override_str = '';
@@ -103,6 +105,7 @@ exit 1 unless GetOptions(
     'enable-auto-block-tests' => \$enable_auto_block_tests,
     'List-mode'           => \$list_mode,
     'diff'                => \$diff_mode,
+    'test-limit=i'        => \$test_limit,
     'help'                => \$help
 );
 
@@ -769,6 +772,18 @@ my @tests = (
         'exec_err'  => $NO,
         'fatal'     => $NO
     },
+    {
+        'category'  => 'operations',
+        'detail'    => 'psad.conf ignore eth1 traffic',
+        'err_msg'   => 'did not ignore eth1 traffic',
+        'negative_output_matches' => [qr/SRC\:\s+192\.168\.10\.55/],
+        'match_all' => $MATCH_ALL_RE,
+        'function'  => \&generic_exec,
+        'cmdline'   => "$psadCmd --test-mode -A --analysis-write-data --auto-dl $dl5_ipv4_auto_dl_file " .
+                "-m $scans_dir/" .  &fw_type() . "/$syn_scan_file -c $ignore_intf_conf $normal_root_override_str",
+        'exec_err'  => $NO,
+        'fatal'     => $NO
+    },
     {
         'category'  => 'operations',
         'detail'    => 'psad.conf require DROP prefix',
@@ -977,6 +992,7 @@ if ($saved_last_results) {
 ### main loop through all of the tests
 for my $test_hr (@tests) {
     &run_test($test_hr);
+    last if $test_limit > 0 and $executed >= $test_limit;
 }
 
 &logr("\n[+] passed/failed/executed: $passed/$failed/$executed tests\n\n");
